@@ -53,7 +53,7 @@ G_BEGIN_DECLS
 #endif /* !G_ENABLE_DEBUG */
 
 
-/* BOOLEAN:STRING,INT,UINT (/usr/src/ports/mate-terminal/mate-terminal-1.10.1-1.i686/src/mate-terminal-1.10.1/src/terminal-marshal.list:1) */
+/* BOOLEAN:STRING,INT,UINT (/usr/src/ports/mate-terminal/mate-terminal-1.18.0-1.x86_64/src/mate-terminal-1.18.0/src/terminal-marshal.list:1) */
 G_GNUC_INTERNAL void _terminal_marshal_BOOLEAN__STRING_INT_UINT (GClosure     *closure,
                                                                  GValue       *return_value,
                                                                  guint         n_param_values,
@@ -73,9 +73,9 @@ _terminal_marshal_BOOLEAN__STRING_INT_UINT (GClosure     *closure,
                                                              gint         arg_2,
                                                              guint        arg_3,
                                                              gpointer     data2);
-  register GMarshalFunc_BOOLEAN__STRING_INT_UINT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__STRING_INT_UINT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
